"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var http_client_1 = require("./http-client");
var sl_routes_1 = require("./sl-routes");
var entities_mapper_1 = require("./entities-mapper");
var BackendProxy = /** @class */ (function () {
    function BackendProxy(config, logger) {
        this.config = config;
        this.logger = logger;
        this.client = new http_client_1.HttpClient(this.config, this.logger);
    }
    BackendProxy.prototype.getBuildSession = function (buildSessionId, callback) {
        var _this = this;
        var url = sl_routes_1.SLRoutes.buildSessionV2(buildSessionId);
        this.client.get(url, function (err, httpResponse) {
            _this.invokeCallback(callback, err, httpResponse, entities_mapper_1.EntitiesMapper.toGetBuildSessionIdResponse);
        });
    };
    BackendProxy.prototype.createBuildSessionId = function (request, callback) {
        var _this = this;
        var url = sl_routes_1.SLRoutes.buildSessionV2();
        this.client.post(request, url, function (err, httpResponse) {
            _this.invokeCallback(callback, err, httpResponse, entities_mapper_1.EntitiesMapper.toCreateBuildSessionIdResponse);
        });
    };
    BackendProxy.prototype.invokeCallback = function (callback, err, httpResponse, map) {
        if (callback == null) {
            throw new Error("'callback' cannot be null");
        }
        if (err != null) {
            return callback(err, httpResponse);
        }
        if (map == null) {
            return callback(null, httpResponse);
        }
        var apiResponse = map(httpResponse);
        return callback(null, apiResponse);
    };
    return BackendProxy;
}());
exports.BackendProxy = BackendProxy;
